==> segatex-8.520.tar.gz: segatex-8.520/src/semanage_core_translation_process.cpp <==
/*
 * segatex SELinux tool.
 *
 * Copyright (C) 2007-2014 Shintaro Fujiwara 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * */

#include <qlayout.h>
#include <qpushbutton.h>
#include <qradiobutton.h>
#include <q3buttongroup.h>
#include <qlineedit.h>
#include <q3textedit.h>
//Added by qt3to4:
#include <Q3TextStream>
#include <QHBoxLayout>
#include <QVBoxLayout>
#include <QLabel>

#include <unistd.h>
#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <fstream>

#include "semanage_core_translation_process.h"
//#include "editor.h"

#include <iostream>
using namespace std;

//default constructor
SemanageCoreTranslationProcess::SemanageCoreTranslationProcess(QWidget *parent, const char *name): QDialog(parent, name)
{
	setCaption(tr("Semanage Translation Process"));
	textEdit1 = new Q3TextEdit(this);
	textEdit1->setPaletteBackgroundColor(QColor(250,180,200));

	semanageEditLabel = new QLabel(tr("Add translation(translation_name):"), this );
	semanageEditLineEdit = new QLineEdit( this );
	semanageEditLineEdit->setText("");
	semanageEditLineEdit->setPaletteBackgroundColor(QColor(255,100,200));
	semanageEditLabel2 = new QLabel(tr("level:"), this );
	semanageEditLineEdit2 = new QLineEdit( this );
	semanageEditLineEdit2->setText("");
	semanageEditLineEdit2->setPaletteBackgroundColor(QColor(255,100,200));
	addButton = new QPushButton(tr("Add translation"), this);
	addButton->setPaletteBackgroundColor(QColor(200,157,100));
	connect(addButton, SIGNAL(clicked()), this, SLOT(add_button_clicked()));

	semanageEditLabel3 = new QLabel(tr("Delete translation(translation_name):"), this );
	semanageEditLineEdit3 = new QLineEdit( this );
	semanageEditLineEdit3->setText("");
	semanageEditLineEdit3->setPaletteBackgroundColor(QColor(255,100,200));
	semanageEditLabel7 = new QLabel(tr("level:"), this );
	semanageEditLineEdit7 = new QLineEdit( this );
	semanageEditLineEdit7->setText("");
	semanageEditLineEdit7->setPaletteBackgroundColor(QColor(255,100,200));
	deleteButton = new QPushButton(tr("Delete translation"), this);
	deleteButton->setPaletteBackgroundColor(QColor(200,157,100));
	connect(deleteButton, SIGNAL(clicked()), this, SLOT(delete_button_clicked()));

	semanageEditLabel4 = new QLabel(tr("Modify translation(translation_name):"), this );
	semanageEditLineEdit4 = new QLineEdit( this );
	semanageEditLineEdit4->setText("New_translation_name");
	semanageEditLineEdit4->setPaletteBackgroundColor(QColor(255,100,200));
	semanageEditLabel5 = new QLabel(tr("level:"), this );
	semanageEditLineEdit5 = new QLineEdit( this );
	semanageEditLineEdit5->setText("Level defined in translation");
	semanageEditLineEdit5->setPaletteBackgroundColor(QColor(255,100,200));
	modifyButton = new QPushButton(tr("Modify translation"), this);
	modifyButton->setPaletteBackgroundColor(QColor(200,157,100));
	connect(modifyButton, SIGNAL(clicked()), this, SLOT(modify_button_clicked()));

	closeButton = new QPushButton(tr("close"), this);
	//closing process button
	connect(closeButton, SIGNAL(clicked()), this, SLOT(close()));
	closeButton->setDefault(true);

	//set textEdit smanage such and such -l
	semanage_core_base_translation_process();

	mainLayout = new QVBoxLayout(this);
	mainLayout->setMargin(11);

	upperLayout = new QVBoxLayout;
	upperLayout->addWidget(textEdit1);

	middleLayout = new QVBoxLayout;
	leftLayout = new QHBoxLayout;
	rightLayout = new QHBoxLayout;
	thirdLayout = new QHBoxLayout;
	
	leftLayout->addWidget(semanageEditLabel);
	leftLayout->addWidget(semanageEditLineEdit);
	leftLayout->addWidget(semanageEditLabel2);
	leftLayout->addWidget(semanageEditLineEdit2);
	leftLayout->addWidget(addButton);
	rightLayout->addWidget(semanageEditLabel3);
	rightLayout->addWidget(semanageEditLineEdit3);
	rightLayout->addWidget(semanageEditLabel7);
	rightLayout->addWidget(semanageEditLineEdit7);
	rightLayout->addWidget(deleteButton);
	thirdLayout->addWidget(semanageEditLabel4);
	thirdLayout->addWidget(semanageEditLineEdit4);
	thirdLayout->addWidget(semanageEditLabel5);
	thirdLayout->addWidget(semanageEditLineEdit5);
	thirdLayout->addWidget(modifyButton);

	middleLayout->addLayout(leftLayout);
	middleLayout->addLayout(rightLayout);
	middleLayout->addLayout(thirdLayout);

	footLayout = new QHBoxLayout;
	footLayout->addStretch();
	footLayout->addWidget(closeButton);

	mainLayout->addLayout(upperLayout);
	mainLayout->addLayout(middleLayout);
	mainLayout->addLayout(footLayout);
	resize(1100,600);
}

/*signal and slot should have same argument pattern so I had to pass to another slot*/
void SemanageCoreTranslationProcess::add_button_clicked()
{
	semanageEditLineEdit_str = semanageEditLineEdit->text();
	semanageEditLineEdit2_str = semanageEditLineEdit2->text();
	add_button_clicked_process(semanageEditLineEdit_str,semanageEditLineEdit2_str);
}
/*signal and slot should have same argument pattern so I had to pass to another slot*/
void SemanageCoreTranslationProcess::delete_button_clicked()
{
	semanageEditLineEdit3_str = semanageEditLineEdit3->text();
	semanageEditLineEdit7_str = semanageEditLineEdit7->text();
	delete_button_clicked_process(semanageEditLineEdit3_str, semanageEditLineEdit7_str);
}
/*signal and slot should have same argument pattern so I had to pass to another slot*/
void SemanageCoreTranslationProcess::modify_button_clicked()
{
	semanageEditLineEdit4_str = semanageEditLineEdit4->text();
	semanageEditLineEdit5_str = semanageEditLineEdit5->text();
	modify_button_clicked_process(semanageEditLineEdit4_str,semanageEditLineEdit5_str);
}
/* this slot does just make .pp file */
void SemanageCoreTranslationProcess::add_button_clicked_process(QString semanageEditLineEdit_str, QString semanageEditLineEdit2_str)
{
	semanageEditLineEdit_str_pp = "semanage translation -a -T " + semanageEditLineEdit_str + " " + semanageEditLineEdit2_str;
        #define PWD_BUF 8600
        const char* make_module_file="/usr/share/segatex/semanage/add_translationed";
        ofstream os_add;
        os_add.open(make_module_file);
        if(os_add){
                FILE *read_fp;
                #define SIZE_TMP 8600
                char buffer[SIZE_TMP];
                int chars_read;
                memset(buffer, '\0', sizeof(buffer));
                read_fp = popen(semanageEditLineEdit_str_pp, "r");
                if(read_fp != NULL){
                        chars_read = fread(buffer, sizeof(char), SIZE_TMP, read_fp);
                        while(chars_read>0){
                                buffer[chars_read -1] = '\0';
                                //os << "Reading:-" << endl;
                                os_add << buffer << endl;
                                chars_read= fread(buffer, sizeof(char), SIZE_TMP, read_fp);
                        }
                        pclose(read_fp);
                }
        }
	os_add.close();
	//set textEdit semanage -l
	semanage_core_base_translation_process();
	//outputfile_str_common2 = make_module_file;
}
/* this slot does just make .pp file */
void SemanageCoreTranslationProcess::delete_button_clicked_process(QString semanageEditLineEdit3_str, QString semanageEditLineEdit7_str)
{
	semanageEditLineEdit_str_pp = "semanage translation -d -T " + semanageEditLineEdit3_str + " " + semanageEditLineEdit7_str;
	//for debug
	//cout << "semanageEditLineEdit_str_pp:" << semanageEditLineEdit_str_pp << endl;
	//

        #define PWD_BUF 8600
        const char* make_module_file="/usr/share/segatex/semanage/delete_translationed";
        ofstream os_delete;
        os_delete.open(make_module_file);
        if(os_delete){
                FILE *read_fp;
                #define SIZE_TMP 8600
                char buffer[SIZE_TMP];
                int chars_read;
                memset(buffer, '\0', sizeof(buffer));
                read_fp = popen(semanageEditLineEdit_str_pp, "r");
                if(read_fp != NULL){
                        chars_read = fread(buffer, sizeof(char), SIZE_TMP, read_fp);
                        while(chars_read>0){
                                buffer[chars_read -1] = '\0';
                                //os << "Reading:-" << endl;
                                os_delete << buffer << endl;
                                chars_read= fread(buffer, sizeof(char), SIZE_TMP, read_fp);
                        }
                        pclose(read_fp);
                }
        }
	os_delete.close();
	//set textEdit semanage -l
	semanage_core_base_translation_process();
	//outputfile_str_common2 = make_module_file;
}
/* this slot does just make .pp file */
void SemanageCoreTranslationProcess::modify_button_clicked_process(QString semanageEditLineEdit4_str, QString semanageEditLineEdit5_str)
{
	semanageEditLineEdit_str_pp = "semanage translation -m -T " + semanageEditLineEdit4_str + " " + semanageEditLineEdit5_str;
        #define PWD_BUF 8600
        const char* make_module_file="/usr/share/segatex/semanage/modify_translationed";
        ofstream os_modify;
        os_modify.open(make_module_file);
        if(os_modify){
                FILE *read_fp;
                #define SIZE_TMP 8600
                char buffer[SIZE_TMP];
                int chars_read;
                memset(buffer, '\0', sizeof(buffer));
                read_fp = popen(semanageEditLineEdit_str_pp, "r");
                if(read_fp != NULL){
                        chars_read = fread(buffer, sizeof(char), SIZE_TMP, read_fp);
                        while(chars_read>0){
                                buffer[chars_read -1] = '\0';
                                //os << "Reading:-" << endl;
                                os_modify << buffer << endl;
                                chars_read= fread(buffer, sizeof(char), SIZE_TMP, read_fp);
                        }
                        pclose(read_fp);
                }
        }
	os_modify.close();
	//set textEdit semanage -l
	semanage_core_base_translation_process();
}

// {boolean|login|user|port|interface|fcontext|translation}

void SemanageCoreTranslationProcess::semanage_core_base_translation_process()
{
        #define PWD_BUF 8600
        const char* semanage_translation_list_file="/usr/share/segatex/semanage/1_translation";
        ofstream os_test;
        os_test.open(semanage_translation_list_file);
        if(os_test){
                FILE *read_fp;
                #define SIZE_TMP 8600
                char buffer[SIZE_TMP];
                int chars_read;
                memset(buffer, '\0', sizeof(buffer));

                read_fp = popen("export LANG=C;/usr/sbin/semanage translation -l", "r");
                if(read_fp != NULL){
                        chars_read = fread(buffer, sizeof(char), SIZE_TMP, read_fp);
                        while(chars_read>0){
                                buffer[chars_read -1] = '\0';
                                //os << "Reading:-" << endl;
                                os_test << buffer;
                                chars_read= fread(buffer, sizeof(char), SIZE_TMP, read_fp);
			}
			pclose(read_fp);
                }
        }
	os_test.close();
	//outputfile_str_common = "translation_list";
	readFromOutputFile();
}

//this slot should be called from above slot
void SemanageCoreTranslationProcess::readFromOutputFile()
{
	/////////////////////////////////////////////////////////////
	path = "/usr/share/segatex/semanage";
	/////////////////////////////////////////////////////////////
	forward_slash = "/";
	dir.setPath(path);
	dir_name = dir.absPath();
	/////////////////////////////////////////////////////////////
	dir.setFilter( QDir::Files );
        dir.setSorting( QDir::Name );
	files = dir.entryList("*translation");
	/////////////////////////////////////////////////////////////
	it_d = files.begin();
	int order_x;
	order_x = 1;
	//first clear it all, unless double the file.
	textEdit1->clear();
		while(it_d != files.end()){
			name = *it_d;
			file_interface_name = dir_name + forward_slash + name;
			QFile file( file_interface_name );
			if ( file.open( QIODevice::ReadOnly ) ) {
				Q3TextStream stream( &file );
				////////////////////////////////////////////
				//int i,j,k,l,m,n;	
				if(order_x == 1)
					textEdit1->append("#########translation list#########");
					textEdit1->append("");
				while ( !stream.atEnd() ) {
					line_analized = stream.readLine(); // line of text excluding '\n'
					textEdit1->append(line_analized);
				}
				textEdit1->setCursorPosition(0,0);
				order_x++;
				++it_d;
			}else{
				//do nothing
			}
			file.close();
		}
}

==> segatex-8.530.tar.gz: segatex-8.530/src/semanage_core_translation_process.cpp <==
/*
 * segatex SELinux tool.
 *
 * Copyright (C) 2007-2014 Shintaro Fujiwara 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * */

#include <QLayout>
#include <QPushButton>
#include <QRadioButton>
#include <QButtonGroup>
#include <QLineEdit>
#include <QTextEdit>
#include <QTextStream>
#include <QHBoxLayout>
#include <QVBoxLayout>
#include <QLabel>

#include <unistd.h>
#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <fstream>

#include "semanage_core_translation_process.h"
//#include "editor.h"

#include <iostream>
using namespace std;

//default constructor
SemanageCoreTranslationProcess::SemanageCoreTranslationProcess(QWidget *parent, const char *name): QDialog(parent, name)
{
	setCaption(tr("Semanage Translation Process"));
	textEdit1 = new QTextEdit(this);
	textEdit1->setPaletteBackgroundColor(QColor(250,180,200));

	semanageEditLabel = new QLabel(tr("Add translation(translation_name):"), this );
	semanageEditLineEdit = new QLineEdit( this );
	semanageEditLineEdit->setText("");
	semanageEditLineEdit->setPaletteBackgroundColor(QColor(255,100,200));
	semanageEditLabel2 = new QLabel(tr("level:"), this );
	semanageEditLineEdit2 = new QLineEdit( this );
	semanageEditLineEdit2->setText("");
	semanageEditLineEdit2->setPaletteBackgroundColor(QColor(255,100,200));
	addButton = new QPushButton(tr("Add translation"), this);
	addButton->setPaletteBackgroundColor(QColor(200,157,100));
	connect(addButton, SIGNAL(clicked()), this, SLOT(add_button_clicked()));

	semanageEditLabel3 = new QLabel(tr("Delete translation(translation_name):"), this );
	semanageEditLineEdit3 = new QLineEdit( this );
	semanageEditLineEdit3->setText("");
	semanageEditLineEdit3->setPaletteBackgroundColor(QColor(255,100,200));
	semanageEditLabel7 = new QLabel(tr("level:"), this );
	semanageEditLineEdit7 = new QLineEdit( this );
	semanageEditLineEdit7->setText("");
	semanageEditLineEdit7->setPaletteBackgroundColor(QColor(255,100,200));
	deleteButton = new QPushButton(tr("Delete translation"), this);
	deleteButton->setPaletteBackgroundColor(QColor(200,157,100));
	connect(deleteButton, SIGNAL(clicked()), this, SLOT(delete_button_clicked()));

	semanageEditLabel4 = new QLabel(tr("Modify translation(translation_name):"), this );
	semanageEditLineEdit4 = new QLineEdit( this );
	semanageEditLineEdit4->setText("New_translation_name");
	semanageEditLineEdit4->setPaletteBackgroundColor(QColor(255,100,200));
	semanageEditLabel5 = new QLabel(tr("level:"), this );
	semanageEditLineEdit5 = new QLineEdit( this );
	semanageEditLineEdit5->setText("Level defined in translation");
	semanageEditLineEdit5->setPaletteBackgroundColor(QColor(255,100,200));
	modifyButton = new QPushButton(tr("Modify translation"), this);
	modifyButton->setPaletteBackgroundColor(QColor(200,157,100));
	connect(modifyButton, SIGNAL(clicked()), this, SLOT(modify_button_clicked()));

	closeButton = new QPushButton(tr("close"), this);
	//closing process button
	connect(closeButton, SIGNAL(clicked()), this, SLOT(close()));
	closeButton->setDefault(true);

	//set textEdit smanage such and such -l
	semanage_core_base_translation_process();

	mainLayout = new QVBoxLayout(this);
	mainLayout->setMargin(11);

	upperLayout = new QVBoxLayout;
	upperLayout->addWidget(textEdit1);

	middleLayout = new QVBoxLayout;
	leftLayout = new QHBoxLayout;
	rightLayout = new QHBoxLayout;
	thirdLayout = new QHBoxLayout;
	
	leftLayout->addWidget(semanageEditLabel);
	leftLayout->addWidget(semanageEditLineEdit);
	leftLayout->addWidget(semanageEditLabel2);
	leftLayout->addWidget(semanageEditLineEdit2);
	leftLayout->addWidget(addButton);
	rightLayout->addWidget(semanageEditLabel3);
	rightLayout->addWidget(semanageEditLineEdit3);
	rightLayout->addWidget(semanageEditLabel7);
	rightLayout->addWidget(semanageEditLineEdit7);
	rightLayout->addWidget(deleteButton);
	thirdLayout->addWidget(semanageEditLabel4);
	thirdLayout->addWidget(semanageEditLineEdit4);
	thirdLayout->addWidget(semanageEditLabel5);
	thirdLayout->addWidget(semanageEditLineEdit5);
	thirdLayout->addWidget(modifyButton);

	middleLayout->addLayout(leftLayout);
	middleLayout->addLayout(rightLayout);
	middleLayout->addLayout(thirdLayout);

	footLayout = new QHBoxLayout;
	footLayout->addStretch();
	footLayout->addWidget(closeButton);

	mainLayout->addLayout(upperLayout);
	mainLayout->addLayout(middleLayout);
	mainLayout->addLayout(footLayout);
	resize(1100,600);
}

/*signal and slot should have same argument pattern so I had to pass to another slot*/
void SemanageCoreTranslationProcess::add_button_clicked()
{
	semanageEditLineEdit_str = semanageEditLineEdit->text();
	semanageEditLineEdit2_str = semanageEditLineEdit2->text();
	add_button_clicked_process(semanageEditLineEdit_str,semanageEditLineEdit2_str);
}
/*signal and slot should have same argument pattern so I had to pass to another slot*/
void SemanageCoreTranslationProcess::delete_button_clicked()
{
	semanageEditLineEdit3_str = semanageEditLineEdit3->text();
	semanageEditLineEdit7_str = semanageEditLineEdit7->text();
	delete_button_clicked_process(semanageEditLineEdit3_str, semanageEditLineEdit7_str);
}
/*signal and slot should have same argument pattern so I had to pass to another slot*/
void SemanageCoreTranslationProcess::modify_button_clicked()
{
	semanageEditLineEdit4_str = semanageEditLineEdit4->text();
	semanageEditLineEdit5_str = semanageEditLineEdit5->text();
	modify_button_clicked_process(semanageEditLineEdit4_str,semanageEditLineEdit5_str);
}
/* this slot does just make .pp file */
void SemanageCoreTranslationProcess::add_button_clicked_process(QString semanageEditLineEdit_str, QString semanageEditLineEdit2_str)
{
	semanageEditLineEdit_str_pp = "semanage translation -a -T " + semanageEditLineEdit_str + " " + semanageEditLineEdit2_str;
        #define PWD_BUF 8600
        const char* make_module_file="/usr/share/segatex/semanage/add_translationed";
        ofstream os_add;
        os_add.open(make_module_file);
        if(os_add){
                FILE *read_fp;
                #define SIZE_TMP 8600
                char buffer[SIZE_TMP];
                int chars_read;
                memset(buffer, '\0', sizeof(buffer));
                read_fp = popen(semanageEditLineEdit_str_pp, "r");
                if(read_fp != NULL){
                        chars_read = fread(buffer, sizeof(char), SIZE_TMP, read_fp);
                        while(chars_read>0){
                                buffer[chars_read -1] = '\0';
                                //os << "Reading:-" << endl;
                                os_add << buffer << endl;
                                chars_read= fread(buffer, sizeof(char), SIZE_TMP, read_fp);
                        }
                        pclose(read_fp);
                }
        }
	os_add.close();
	//set textEdit semanage -l
	semanage_core_base_translation_process();
	//outputfile_str_common2 = make_module_file;
}
/* this slot does just make .pp file */
void SemanageCoreTranslationProcess::delete_button_clicked_process(QString semanageEditLineEdit3_str, QString semanageEditLineEdit7_str)
{
	semanageEditLineEdit_str_pp = "semanage translation -d -T " + semanageEditLineEdit3_str + " " + semanageEditLineEdit7_str;
	//for debug
	//cout << "semanageEditLineEdit_str_pp:" << semanageEditLineEdit_str_pp << endl;
	//

        #define PWD_BUF 8600
        const char* make_module_file="/usr/share/segatex/semanage/delete_translationed";
        ofstream os_delete;
        os_delete.open(make_module_file);
        if(os_delete){
                FILE *read_fp;
                #define SIZE_TMP 8600
                char buffer[SIZE_TMP];
                int chars_read;
                memset(buffer, '\0', sizeof(buffer));
                read_fp = popen(semanageEditLineEdit_str_pp, "r");
                if(read_fp != NULL){
                        chars_read = fread(buffer, sizeof(char), SIZE_TMP, read_fp);
                        while(chars_read>0){
                                buffer[chars_read -1] = '\0';
                                //os << "Reading:-" << endl;
                                os_delete << buffer << endl;
                                chars_read= fread(buffer, sizeof(char), SIZE_TMP, read_fp);
                        }
                        pclose(read_fp);
                }
        }
	os_delete.close();
	//set textEdit semanage -l
	semanage_core_base_translation_process();
	//outputfile_str_common2 = make_module_file;
}
/* this slot does just make .pp file */
void SemanageCoreTranslationProcess::modify_button_clicked_process(QString semanageEditLineEdit4_str, QString semanageEditLineEdit5_str)
{
	semanageEditLineEdit_str_pp = "semanage translation -m -T " + semanageEditLineEdit4_str + " " + semanageEditLineEdit5_str;
        #define PWD_BUF 8600
        const char* make_module_file="/usr/share/segatex/semanage/modify_translationed";
        ofstream os_modify;
        os_modify.open(make_module_file);
        if(os_modify){
                FILE *read_fp;
                #define SIZE_TMP 8600
                char buffer[SIZE_TMP];
                int chars_read;
                memset(buffer, '\0', sizeof(buffer));
                read_fp = popen(semanageEditLineEdit_str_pp, "r");
                if(read_fp != NULL){
                        chars_read = fread(buffer, sizeof(char), SIZE_TMP, read_fp);
                        while(chars_read>0){
                                buffer[chars_read -1] = '\0';
                                //os << "Reading:-" << endl;
                                os_modify << buffer << endl;
                                chars_read= fread(buffer, sizeof(char), SIZE_TMP, read_fp);
                        }
                        pclose(read_fp);
                }
        }
	os_modify.close();
	//set textEdit semanage -l
	semanage_core_base_translation_process();
}

// {boolean|login|user|port|interface|fcontext|translation}

void SemanageCoreTranslationProcess::semanage_core_base_translation_process()
{
        #define PWD_BUF 8600
        const char* semanage_translation_list_file="/usr/share/segatex/semanage/1_translation";
        ofstream os_test;
        os_test.open(semanage_translation_list_file);
        if(os_test){
                FILE *read_fp;
                #define SIZE_TMP 8600
                char buffer[SIZE_TMP];
                int chars_read;
                memset(buffer, '\0', sizeof(buffer));

                read_fp = popen("export LANG=C;/usr/sbin/semanage translation -l", "r");
                if(read_fp != NULL){
                        chars_read = fread(buffer, sizeof(char), SIZE_TMP, read_fp);
                        while(chars_read>0){
                                buffer[chars_read -1] = '\0';
                                //os << "Reading:-" << endl;
                                os_test << buffer;
                                chars_read= fread(buffer, sizeof(char), SIZE_TMP, read_fp);
			}
			pclose(read_fp);
                }
        }
	os_test.close();
	//outputfile_str_common = "translation_list";
	readFromOutputFile();
}

//this slot should be called from above slot
void SemanageCoreTranslationProcess::readFromOutputFile()
{
	/////////////////////////////////////////////////////////////
	path = "/usr/share/segatex/semanage";
	/////////////////////////////////////////////////////////////
	forward_slash = "/";
	dir.setPath(path);
	dir_name = dir.absPath();
	/////////////////////////////////////////////////////////////
	dir.setFilter( QDir::Files );
        dir.setSorting( QDir::Name );
	files = dir.entryList("*translation");
	/////////////////////////////////////////////////////////////
	it_d = files.begin();
	int order_x;
	order_x = 1;
	//first clear it all, unless double the file.
	textEdit1->clear();
		while(it_d != files.end()){
			name = *it_d;
			file_interface_name = dir_name + forward_slash + name;
			QFile file( file_interface_name );
			if ( file.open( QIODevice::ReadOnly ) ) {
				QTextStream stream( &file );
				////////////////////////////////////////////
				//int i,j,k,l,m,n;	
				if(order_x == 1)
					textEdit1->append("#########translation list#########");
					textEdit1->append("");
				while ( !stream.atEnd() ) {
					line_analized = stream.readLine(); // line of text excluding '\n'
					textEdit1->append(line_analized);
				}
				//textEdit1->setCursorPosition(0,0);
				order_x++;
				++it_d;
			}else{
				//do nothing
			}
			file.close();
		}
}
